package com.srs.teacher.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.teacher.domain.SysTeacherAppraise;

/**
 * appraiseService接口
 *
 * @author srs
 * @date 2024-06-12
 */
public interface ISysTeacherAppraiseService extends IService<SysTeacherAppraise> {
    /**
     * 查询appraise
     *
     * @param appraiseId appraise主键
     * @return appraise
     */
    public SysTeacherAppraise selectSysTeacherAppraiseByAppraiseId(Long appraiseId);

    /**
     * 查询appraise列表
     *
     * @param sysTeacherAppraise appraise
     * @return appraise集合
     */
    List<SysTeacherAppraise> selectSysTeacherAppraiseList(SysTeacherAppraise sysTeacherAppraise);

    /**
     * 新增appraise
     *
     * @param sysTeacherAppraise appraise
     * @return 结果
     */
    int insertSysTeacherAppraise(SysTeacherAppraise sysTeacherAppraise);

    /**
     * 修改appraise
     *
     * @param sysTeacherAppraise appraise
     * @return 结果
     */
    int updateSysTeacherAppraise(SysTeacherAppraise sysTeacherAppraise);

    /**
     * 批量删除appraise
     *
     * @param appraiseIds 需要删除的appraise主键集合
     * @return 结果
     */
    int deleteSysTeacherAppraiseByAppraiseIds(Long[] appraiseIds);

    /**
     * 删除appraise信息
     *
     * @param appraiseId appraise主键
     * @return 结果
     */
    int deleteSysTeacherAppraiseByAppraiseId(Long appraiseId);
}
